"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process = __importStar(require("child_process"));
const utils_1 = require("ts-jest/utils");
const git_1 = require("./git");
const diff_1 = require("./__fixtures__/diff");
const path_1 = __importDefault(require("path"));
jest.mock("child_process");
const mockedChildProcess = utils_1.mocked(child_process, true);
describe("git", () => {
    it("should find the ranges of each staged file", () => {
        expect(git_1.getRangesForDiff(diff_1.hunks)).toMatchSnapshot();
    });
    it("should work for hunks which include only-removal-ranges", () => {
        expect(git_1.getRangesForDiff(diff_1.includingOnlyRemovals)).toMatchSnapshot();
    });
    it("should get the staged diff of a file", () => {
        mockedChildProcess.execSync.mockReturnValue(Buffer.from(diff_1.hunks));
        const diffFromFile = git_1.getDiffForFile("./mockfile.js");
        expect(mockedChildProcess.execSync).toHaveBeenCalled();
        expect(diffFromFile).toContain("diff --git");
        expect(diffFromFile).toContain("@@");
    });
    it("should hit the cached diff of a file", () => {
        jest.mock("child_process").resetAllMocks();
        mockedChildProcess.execSync.mockReturnValueOnce(Buffer.from(diff_1.hunks));
        const diffFromFileA = git_1.getDiffForFile("./mockfileCache.js");
        const diffFromFileB = git_1.getDiffForFile("./mockfileCache.js");
        expect(mockedChildProcess.execSync).toHaveBeenCalledTimes(1);
        expect(diffFromFileA).toEqual(diffFromFileB);
        mockedChildProcess.execSync.mockReturnValueOnce(Buffer.from(diff_1.hunks));
        git_1.getDiffForFile("./mockfileMiss.js");
        expect(mockedChildProcess.execSync).toHaveBeenCalledTimes(2);
    });
    it("should get the list of staged files", () => {
        jest.mock("child_process").resetAllMocks();
        mockedChildProcess.execSync.mockReturnValue(Buffer.from(diff_1.diffFileList));
        const fileList = git_1.getDiffFileList();
        expect(mockedChildProcess.execSync).toHaveBeenCalled();
        expect(fileList).toEqual(["file1", "file2", "file3"].map((p) => path_1.default.resolve(p)));
    });
});
//# sourceMappingURL=git.test.js.map